==> huaweicloudsdkdc-3.1.111-py2.py3-none-any.whl: huaweicloudsdkdc/v3/model/update_vif_peer_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateVifPeerRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'vif_peer': 'UpdateVifPeer'
    }

    attribute_map = {
        'vif_peer': 'vif_peer'
    }

    def __init__(self, vif_peer=None):
        """UpdateVifPeerRequestBody

        The model defined in huaweicloud sdk

        :param vif_peer: 
        :type vif_peer: :class:`huaweicloudsdkdc.v3.UpdateVifPeer`
        """
        
        

        self._vif_peer = None
        self.discriminator = None

        if vif_peer is not None:
            self.vif_peer = vif_peer

    @property
    def vif_peer(self):
        """Gets the vif_peer of this UpdateVifPeerRequestBody.

        :return: The vif_peer of this UpdateVifPeerRequestBody.
        :rtype: :class:`huaweicloudsdkdc.v3.UpdateVifPeer`
        """
        return self._vif_peer

    @vif_peer.setter
    def vif_peer(self, vif_peer):
        """Sets the vif_peer of this UpdateVifPeerRequestBody.

        :param vif_peer: The vif_peer of this UpdateVifPeerRequestBody.
        :type vif_peer: :class:`huaweicloudsdkdc.v3.UpdateVifPeer`
        """
        self._vif_peer = vif_peer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVifPeerRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdc-3.1.143-py2.py3-none-any.whl: huaweicloudsdkdc/v3/model/update_vif_peer_request_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateVifPeerRequestBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'vif_peer': 'UpdateVifPeer'
    }

    attribute_map = {
        'vif_peer': 'vif_peer'
    }

    def __init__(self, vif_peer=None):
        r"""UpdateVifPeerRequestBody

        The model defined in huaweicloud sdk

        :param vif_peer: 
        :type vif_peer: :class:`huaweicloudsdkdc.v3.UpdateVifPeer`
        """
        
        

        self._vif_peer = None
        self.discriminator = None

        if vif_peer is not None:
            self.vif_peer = vif_peer

    @property
    def vif_peer(self):
        r"""Gets the vif_peer of this UpdateVifPeerRequestBody.

        :return: The vif_peer of this UpdateVifPeerRequestBody.
        :rtype: :class:`huaweicloudsdkdc.v3.UpdateVifPeer`
        """
        return self._vif_peer

    @vif_peer.setter
    def vif_peer(self, vif_peer):
        r"""Sets the vif_peer of this UpdateVifPeerRequestBody.

        :param vif_peer: The vif_peer of this UpdateVifPeerRequestBody.
        :type vif_peer: :class:`huaweicloudsdkdc.v3.UpdateVifPeer`
        """
        self._vif_peer = vif_peer

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateVifPeerRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
